@@ -1,6 +1,7 @@
 // TODO Find a decent logging library?
 pub mod day1;
 pub mod day2;
+pub mod day3;
 
 pub trait PuzzleSolver {
     fn part_one(&self) -> String {
@@ -29,6 +30,7 @@ pub fn new_solver(day: &str, input: &str) -> Option<Box<dyn PuzzleSolver>> {
     match day {
         "1" => Some(Box::new(day1::Solver::new(input))),
         "2" => Some(Box::new(day2::Solver::new(input))),
+        "3" => Some(Box::new(day3::Solver::new(input))),
         _ => None,
     }
 }
